==> lack-0.3.tar.gz: lack-0.3/find.ml <==
(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Foobar is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Printf

let find base tag =
  let cmd = sprintf "find %s -wholename */%s/*" base tag in
  let inchan = Unix.open_process_in cmd in
  let rec aux l =
    try
      let line = input_line inchan in
        aux (line::l)
    with
        End_of_file -> ignore (Unix.close_process_in inchan); l
  in
    aux []

let find_meta base =
  let cmd = sprintf "find %s -maxdepth 3 -type f -name meta.xml" base in
  let inchan = Unix.open_process_in cmd in
  let rec aux l =
    try
      let line = input_line inchan in
        aux (line::l)
    with
        End_of_file -> ignore (Unix.close_process_in inchan); l
  in
    aux []

==> lack-1.1.tar.gz: lack-1.1/find.ml <==
(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Lack is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Lack.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Printf

let find ?(verbose=false) base tag =
  let cmd = sprintf "find '%s' -wholename '*/%s/*'" base tag in
  let inchan = if verbose then print_endline cmd; Unix.open_process_in cmd in
  let rec aux l =
    try
      let line = input_line inchan in
        aux (line::l)
    with
        End_of_file -> ignore (Unix.close_process_in inchan); l
  in
    aux []

let find_meta base =
  let cmd = sprintf "ls %s/*/current/meta.xml" base in
  let inchan = Unix.open_process_in cmd in
  let rec aux l =
    try
      let line = input_line inchan in
        aux (line::l)
    with
        End_of_file -> ignore (Unix.close_process_in inchan); l
  in
    aux []
